==> libapache-poi-java_3.10.1.orig.tar.xz: apache-poi-3.10.1/src/testcases/org/apache/poi/util/AllPOIUtilTests.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.util;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Test suite for all sub-packages of org.apache.poi.util<br/>
 */
public final class AllPOIUtilTests {
    public static Test suite() {
        TestSuite result = new TestSuite(AllPOIUtilTests.class.getName());
        result.addTestSuite(TestArrayUtil.class);
        result.addTestSuite(TestBinaryTree.class);
        result.addTestSuite(TestBitField.class);
        result.addTestSuite(TestByteField.class);
        result.addTestSuite(TestHexDump.class);
        result.addTestSuite(TestIntegerField.class);
        result.addTestSuite(TestIntList.class);
        result.addTestSuite(TestLittleEndian.class);
        result.addTestSuite(TestLongField.class);
        result.addTestSuite(TestPOILogFactory.class);
        result.addTestSuite(TestPOILogger.class);
        result.addTestSuite(TestShortField.class);
        result.addTestSuite(TestShortList.class);
        result.addTestSuite(TestStringUtil.class);
        result.addTestSuite(TestTempFile.class);
        return result;
    }
}

==> libapache-poi-java_4.0.1.orig.tar.xz: apache-poi-4.0.1/src/testcases/org/apache/poi/util/AllPOIUtilTests.java <==
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */

package org.apache.poi.util;

import org.junit.runner.RunWith;
import org.junit.runners.Suite;

/**
 * Test suite for all sub-packages of org.apache.poi.util<br>
 */
@RunWith(Suite.class)
@Suite.SuiteClasses({
      TestArrayUtil.class
    , TestBitField.class
    , TestByteField.class
    , TestHexDump.class
    , TestIntegerField.class
    , TestIntList.class
    , TestLittleEndian.class
    , TestLongField.class
    , TestPOILogFactory.class
    , TestPOILogger.class
    , TestShortField.class
    , TestStringUtil.class
    , TestTempFile.class
})
public final class AllPOIUtilTests {
}
